==> eclipse-2.1.3_1.tgz: org/eclipse/jdt/internal/debug/eval/ast/instructions/PushThis.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.debug.eval.ast.instructions;


import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.Status;
import org.eclipse.jdt.debug.core.IJavaObject;
import org.eclipse.jdt.internal.debug.core.JDIDebugPlugin;
import org.eclipse.jdt.internal.debug.core.model.JDIObjectValue;
import org.eclipse.jdt.internal.debug.eval.ast.engine.IRuntimeContext;
 
/**
 * Pushes the 'this' object onto the stack.
 */
public class PushThis extends SimpleInstruction {
	
	private int fEnclosingLevel;
	
	public PushThis(int enclosingLevel) {
		fEnclosingLevel= enclosingLevel;
	}
	
	public void execute() throws CoreException {
		IRuntimeContext context= getContext();
		IJavaObject thisInstance = context.getThis();
		if (thisInstance == null) {
			// static context
			push(context.getReceivingType());
		} else {
			if (fEnclosingLevel != 0) {
				thisInstance= ((JDIObjectValue)thisInstance).getEnclosingObject(fEnclosingLevel);
				if (thisInstance == null) {
					throw new CoreException(new Status(Status.ERROR, JDIDebugPlugin.getUniqueIdentifier(), Status.OK, InstructionsEvaluationMessages.getString("PushThis.Unable_to_retrieve_the_correct_enclosing_instance_of__this__2"), null)); //$NON-NLS-1$
				}
			}
			push(thisInstance);
		}
	}

	public String toString() {
		return InstructionsEvaluationMessages.getString("PushThis.push___this__1"); //$NON-NLS-1$
	}
}

==> eclipse-3.0.1_2.tgz: org/eclipse/jdt/internal/debug/eval/ast/instructions/PushThis.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.debug.eval.ast.instructions;


import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jdt.debug.core.IJavaObject;
import org.eclipse.jdt.internal.debug.core.JDIDebugPlugin;
import org.eclipse.jdt.internal.debug.core.model.JDIObjectValue;
import org.eclipse.jdt.internal.debug.eval.ast.engine.IRuntimeContext;
 
/**
 * Pushes the 'this' object onto the stack.
 */
public class PushThis extends SimpleInstruction {
	
	private int fEnclosingLevel;
	
	public PushThis(int enclosingLevel) {
		fEnclosingLevel= enclosingLevel;
	}
	
	public void execute() throws CoreException {
		IRuntimeContext context= getContext();
		IJavaObject thisInstance = context.getThis();
		if (thisInstance == null) {
			// static context
			push(context.getReceivingType());
		} else {
			if (fEnclosingLevel != 0) {
				thisInstance= ((JDIObjectValue)thisInstance).getEnclosingObject(fEnclosingLevel);
				if (thisInstance == null) {
					throw new CoreException(new Status(IStatus.ERROR, JDIDebugPlugin.getUniqueIdentifier(), IStatus.OK, InstructionsEvaluationMessages.getString("PushThis.Unable_to_retrieve_the_correct_enclosing_instance_of__this__2"), null)); //$NON-NLS-1$
				}
			}
			push(thisInstance);
		}
	}

	public String toString() {
		return InstructionsEvaluationMessages.getString("PushThis.push___this__1"); //$NON-NLS-1$
	}
}
